@@ -28,6 +28,7 @@ from pygls.lsp.methods import (
     TEXT_DOCUMENT_DID_CLOSE,
     TEXT_DOCUMENT_DID_OPEN,
     TEXT_DOCUMENT_DID_SAVE,
+    TYPE_DEFINITION,
     WORKSPACE_DID_CHANGE_CONFIGURATION,
     WORKSPACE_SYMBOL,
 )
@@ -308,6 +309,23 @@ def definition(
     return definitions if definitions else None
 
 
+@SERVER.feature(TYPE_DEFINITION)
+def type_definition(
+    server: JediLanguageServer, params: TextDocumentPositionParams
+) -> Optional[List[Location]]:
+    """Support Goto Type Definition."""
+    document = server.workspace.get_document(params.text_document.uri)
+    jedi_script = jedi_utils.script(server.project, document)
+    jedi_lines = jedi_utils.line_column(params.position)
+    names = jedi_script.infer(*jedi_lines)
+    definitions = [
+        definition
+        for definition in (jedi_utils.lsp_location(name) for name in names)
+        if definition is not None
+    ]
+    return definitions if definitions else None
+
+
 @SERVER.feature(DOCUMENT_HIGHLIGHT)
 def highlight(
     server: JediLanguageServer, params: TextDocumentPositionParams
